@@ -1,4 +1,4 @@
-#_  __
+#  _  __
 # | |/ /___ ___ _ __  ___ _ _ ®
 # | ' </ -_) -_) '_ \/ -_) '_|
 # |_|\_\___\___| .__/\___|_|
@@ -19,16 +19,19 @@ import base64
 import tempfile
 import logging
 import threading
+
 from Cryptodome.Cipher import AES
 from tabulate import tabulate
 
+from ..display import bcolors
 from ..team import Team
 from .. import api, display, generator
 from ..subfolder import BaseFolderNode, find_folders, try_resolve_path, get_folder_path
-from .base import raise_parse_exception, suppress_exit, user_choice, Command
+from .base import raise_parse_exception, suppress_exit, user_choice, Command, dump_report_data
 from ..record import Record, get_totp_code
 from ..params import KeeperParams, LAST_RECORD_UID
 from ..error import CommandError
+from .enterprise_pb2 import SharedRecordResponse
 
 
 def register_commands(commands):
@@ -47,6 +50,7 @@ def register_commands(commands):
     commands['clipboard-copy'] = ClipboardCommand()
     commands['record-history'] = RecordHistoryCommand()
     commands['totp'] = TotpCommand()
+    commands['shared-records-report'] = SharedRecordsReport()
 
 
 def register_command_info(aliases, command_info):
@@ -62,9 +66,10 @@ def register_command_info(aliases, command_info):
     aliases['cc'] = 'clipboard-copy'
     aliases['find-password'] = ('clipboard-copy', '--output=stdout')
     aliases['rh'] = 'record-history'
+    aliases['srr'] = 'shared-records-report'
 
     for p in [search_parser, list_parser, get_info_parser, clipboard_copy_parser, record_history_parser, totp_parser,  add_parser, edit_parser, rm_parser,
-              append_parser, download_parser, upload_parser, delete_attachment_parser]:
+              append_parser, download_parser, upload_parser, delete_attachment_parser, shared_records_report_parser]:
         command_info[p.prog] = p.description
     command_info['list-sf|lsf'] = 'Display all shared folders'
     command_info['list-team|lt'] = 'Display all teams'
@@ -79,6 +84,7 @@ record_history_parser.exit = suppress_exit
 
 
 totp_parser = argparse.ArgumentParser(prog='totp', description='Display the Two Factor Code for a record.')
+totp_parser.add_argument('-p', '--print', dest='print', action='store_true', help='print TOTP code to standard output')
 totp_parser.add_argument('record', nargs='?', type=str, action='store', help='record path or UID')
 totp_parser.error = raise_parse_exception
 totp_parser.exit = suppress_exit
@@ -174,6 +180,12 @@ delete_attachment_parser.add_argument('record', action='store', help='record pat
 delete_attachment_parser.error = raise_parse_exception
 delete_attachment_parser.exit = suppress_exit
 
+shared_records_report_parser = argparse.ArgumentParser(prog='shared-records-report|srr', description='Report shared records for a logged-in user.')
+shared_records_report_parser.add_argument('--format', dest='format', choices=['json', 'csv', 'table'], default='table', help='Data format output')
+shared_records_report_parser.add_argument('name', type=str, nargs='?', help='file name')
+shared_records_report_parser.error = raise_parse_exception
+shared_records_report_parser.exit = suppress_exit
+
 
 class RecordAddCommand(Command):
     def get_parser(self):
@@ -1438,23 +1450,29 @@ class TotpCommand(Command):
                     else:
                         raise CommandError('totp', 'More than one record are found for search criteria: {0}'.format(kwargs['record']))
 
+        print_totp = kwargs.get('print')
         if record_uid:
             rec = api.get_record(params, record_uid)
-            tmer = None     # type: threading.Timer or None
-            done = False
-            def print_code():
-                global tmer
-                if not done:
-                    TotpCommand.display_code(rec.totp)
-                    tmer = threading.Timer(1, print_code).start()
-            try:
-                print('Press <Enter> to exit\n')
-                print_code()
-                input()
-            finally:
-                done = True
-                if tmer:
-                    tmer.cancel()
+            if print_totp:
+                if rec.totp:
+                    code, remains, total = get_totp_code(rec.totp)
+                    if code: print(code)
+            else:
+                tmer = None     # type: threading.Timer or None
+                done = False
+                def print_code():
+                    global tmer
+                    if not done:
+                        TotpCommand.display_code(rec.totp)
+                        tmer = threading.Timer(1, print_code).start()
+                try:
+                    print('Press <Enter> to exit\n')
+                    print_code()
+                    input()
+                finally:
+                    done = True
+                    if tmer:
+                        tmer.cancel()
         else:
             TotpCommand.find_endpoints(params)
             logging.info('')
@@ -1471,6 +1489,9 @@ class TotpCommand(Command):
             print(tabulate(table, headers=headers))
             print('')
 
+        if print_totp and not record_uid:
+            logging.warning(bcolors.FAIL + '--print option requires valid record UID' + bcolors.ENDC)
+
     LastDisplayedCode = ''
     @staticmethod
     def display_code(url):
@@ -1501,4 +1522,79 @@ class TotpCommand(Command):
                     TotpCommand.Endpoints.append(TotpEndpoint(record_uid, record.title, paths))
 
 
+class SharedRecordsReport(Command):
+    def get_parser(self):
+        return shared_records_report_parser
 
+    def execute(self, params, **kwargs):
+
+        export_format = kwargs['format'] if 'format' in kwargs else None
+        export_name = kwargs['name'] if 'name' in kwargs else None
+
+        rs = api.communicate_rest(params, None, 'report/get_shared_record_report')
+
+        shared_records_data_rs = SharedRecordResponse()
+        shared_records_data_rs.ParseFromString(rs)
+
+        shared_from_mapping = {
+            1: "Direct Share",
+            2: "Share Folder",
+            3: "Share Team Folder"
+        }
+
+        rows = []
+        count = 0
+        for e in shared_records_data_rs.events:
+            count = count + 1
+
+            record_uid = api.decode_uid_to_str(e.recordUid)
+
+            cached_record = None
+
+            if record_uid in params.record_cache:   # to avoid not found warning log messages
+                cached_record = api.get_record(params, record_uid)
+
+            if not cached_record:   # probably deleted record
+                logging.debug("Record uid=%s was not located in current cache." % record_uid)
+                continue
+
+            # Folder Path(s)
+            folders = [get_folder_path(params, x) for x in find_folders(params, record_uid)]
+            path_str = ""
+            for i in range(len(folders)):
+                path_str = path_str + ('{0}{1}'.format('\n' if i > 0 else '', folders[i]))
+
+            if not e.canEdit and not e.canReshare:
+                permissions = "Read Only"
+            elif not e.canEdit and e.canReshare:
+                permissions = "Can Share"
+            elif e.canEdit and e.canReshare:
+                permissions = "Can Edit"
+            else:
+                permissions = "Can Edit & Share"
+
+            row = {
+                'count': count,
+                'uid': record_uid,
+                'title': cached_record.title,
+                'shareTo': e.userName,
+                'sharedFrom': shared_from_mapping[e.shareFrom] if e.shareFrom in shared_from_mapping else "Other Share",
+                'permissions': permissions,
+                'folderPath': path_str
+            }
+
+            rows.append(row)
+
+        fields = ['count', 'uid', 'title', 'shareTo', 'sharedFrom', 'permissions', 'folderPath']
+        field_descriptions = fields
+        if export_format == 'table':
+            field_descriptions = ['#', 'Record UID', 'Title', 'Shared To', 'Shared From', 'Permissions', 'Folder Path']
+
+        table = []
+        for raw in rows:
+            row = []
+            for f in fields:
+                row.append(raw[f])
+            table.append(row)
+
+        dump_report_data(table, field_descriptions, fmt=export_format, filename=export_name)
