@@ -97,7 +97,6 @@ class KeeperParams:
         self.enterprise = None
         self.enterprise_id = 0
         self.msp_tree_key = None
-        self.msp = None
         self.prepare_commands = False
         self.batch_mode = False
         self.__rest_context = RestApiContext(server=server, device_id=device_id)
@@ -106,6 +105,10 @@ class KeeperParams:
         self.record_history = {}        # type: dict[str, (list[dict], int)]
         self.event_queue = []
         self.logout_timer = 0
+        self.login_v3 = True
+        self.clone_code = None
+        self.device_token = None
+        self.device_private_key = None
 
     def clear_session(self):
         self.auth_verifier = ''
@@ -141,7 +144,6 @@ class KeeperParams:
         self.enterprise = None
         self.enterprise_id = 0
         self.msp_tree_key = None
-        self.msp = None
         self.prepare_commands = True
         self.batch_mode = False
         self.pending_share_requests.clear()
@@ -149,6 +151,10 @@ class KeeperParams:
         self.record_history.clear()
         self.event_queue.clear()
         self.logout_timer = self.config.get('logout_timer') or 0
+        # self.login_v3 = self.config.get('login_v3') or True
+        self.clone_code = None
+        self.device_token = None
+        self.device_private_key = None
 
     def __get_rest_context(self):
         return self.__rest_context
